module rx_mac (
  rx_clk,
  reset_n,
  rx_dv,
  rx_error,
  rx_data,
  data,
  rx_status_valid_n,
  rx_status,
  data_valid,
  last_data,
  eth_address
  );
  
input         rx_clk,
              reset_n,
              rx_dv,
              rx_error;
      
input [3:0]   rx_data;
input [47:0]  eth_address;

output        rx_status_valid_n,
              data_valid,
              last_data;
              
output [3:0]  data;
output [15:0] rx_status;

wire          SFD_start_detect,
	      SFD_detected,
              FCS_start_check,
              data_en,
              address_match,
              multicast,
              broadcast,
              crc_ok;
              
wire [3:0]    data_tap,data;

rx_sm rx_sm (
  .clk(rx_clk), 
  .reset_n(reset_n), 
  .rx_dv(rx_dv),
  .rx_error(rx_error), 
  .SFD_detected(SFD_detected),
  .address_match(address_match),
  .multicast(multicast),
  .broadcast(broadcast),
  .crc_ok(crc_ok),
  .SFD_start_detect(SFD_start_detect), 
  .FCS_start_check(FCS_start_check),
  .data_en(data_en),
  .data_valid(data_valid),
  .last_data(last_data),
  .rx_status_valid_n(rx_status_valid_n),
  .rx_status(rx_status)
  );

rx_buffer rx_buffer (
  .clk(rx_clk), 
  .reset_n(reset_n), 
  .rx_data(rx_data), 
  .data_tap(data_tap), 
  .data(data),
  .data_en(data_en)
  );
  
SFD_detector rx_sfd (
  .clk(rx_clk), 
  .reset_n(reset_n), 
  .data_tap(data_tap), 
  .SFD_start_detect(SFD_start_detect), 
  .SFD_detected(SFD_detected)
  );
  
aml rx_aml (
  .clk(rx_clk), 
  .reset_n(reset_n), 
  .data_tap(data_tap), 
  .eth_address(eth_address),
  .SFD_detected(SFD_detected),
  .address_match(address_match),
  .multicast(multicast),
  .broadcast(broadcast)
  );

fcs_check rx_fcs (
  .clk(rx_clk),
  .reset_n(reset_n),
  .FCS_start_check(FCS_start_check),
  .data(data),
  .crc_ok(crc_ok)
  );
  
endmodule